pub fn is_string_null_at(array: &ArrayRef, i: usize) -> boolExpand description
Check whether the string value at index i is null for string or
dictionary-encoded string arrays.
Returns true when the value is null or the array type is not a string
type, which corresponds to string_array_value_at_index returning None.
Panics
If index i is out of bounds.